/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

/*!
 * \brief Class described the camera setting
 * \author elaazzouzi
 * \date 02-11-2016
 */

#ifndef CAMERASETTING_H
#define CAMERASETTING_H

#include "controllers/common/acquisition/detector/DetectorElement.h"
#include "controllers/common/acquisition/detector/DetectorController.h"
#include "drivers/photonic/psl/PslDriver.h"

namespace cyclops {

/**
 * Class providing the Camera parameters.
 */
class CyclopsSetting : public ExperimentController, public controller::Start {

public:
	//! Type of controller
	static const std::string TYPE;
	static const std::string BINNING[5];
	static const std::string MODE[5];

	/**
	 * Constructor.
	 */
	CyclopsSetting(const std::string& name);

	/**
	 * Destructor.
	 */
	virtual ~CyclopsSetting();

	/**
	 * Configuration after controller assignments.
	 */
	virtual void postConfiguration();

	/**
	 * Start command.
	 */
	virtual void start();


	/**
	 * Refreshes binning.
	 */
	void refreshMode(int32 value);
	void updateMode();
	void updateTemperature();
//
//	Property<int32> hflip;
//	Property<int32> vflip;
//	Property<int32> rotate;



	Property<int32, SETPOINT> mode;
	Property<float64> kineTime;
	Property<int32> nbKine;
    Property<int32> gain;
	Property<bool > modeBP;
	Property<std::string> fileDirectory;
	Property<std::string> fileName;

	DriverPtr<psl::PslDriver> m_CamDriver;

};

}

#endif
