/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#include "CAENAdcController.h"
#include "drivers/global/DriversCommands.h"
#include "controllers/common/family/Families.h"
#include <boost/thread/thread.hpp>
#include <controllers/common/acquisition/mode/DPPAcquisitionCommon.h>

using namespace std;
using namespace boost;

namespace npp {

const string CAENAdcController::TYPE = "adc_controller";

/*
 * Constructor
 */
CAENAdcController::CAENAdcController(const string& name) {

	ExperimentController::init(name);
	acquisition::ListModeProperties::init(name);
	ClearData::init(this);

	setFamily(family::ACQUISITION, family::SETTING);

	// Register properties
	modelName.init(this, NOSAVE, "model_name");
	acqBoardIndex.init(this, SAVE, "acq_board_index");
	channels.init(this, NOSAVE, "channels");
	nbChannels.init(this, NOSAVE, "nb_channels");
	dppAcqMode.init(this, NOSAVE, "dpp_acq_mode");
	dppAcqMode.update(acquisition::DPPAcquisitionCommon::LISTMODE_MODE);

	recordLength.init(this, SAVE, "record_length");

	minRange.init(this, NOSAVE, "min_range");
	maxRange.init(this, NOSAVE, "max_range");

	channelActive.init(this, NOSAVE, "channel_active");
	dcOffset.init(this, NOSAVE, "dc_offset");
	pulsePolarity.init(this, NOSAVE, "pulse_polarity");
	preTrigger.init(this, NOSAVE, "pre_trigger");

	curve0.init(this, NOSAVE, "curve0_table");
	curve1.init(this, NOSAVE, "curve1_table");
	curve2.init(this, NOSAVE, "curve2_table");
	curve3.init(this, NOSAVE, "curve3_table");
	curve4.init(this, NOSAVE, "curve4_table");

	enableCoincidence.init(this, NOSAVE, "enable_coincidence");
	coincidenceWindow.init(this, NOSAVE, "coincidence_window");
	coincidenceMask.init(this, NOSAVE, "coincidence_mask");

	registerFunction(TYPE);
}

/*
 * Destructor
 */
CAENAdcController::~CAENAdcController() {

}

void CAENAdcController::refreshDppAcqModeProperty(int32 aValue) throw (CannotSetValue) {
	if (aValue == acquisition::DPPAcquisitionCommon::SCOPE_MODE) {
		scope = true;
	}
	else {
		scope = false;
	}
}


}
