/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#include "RunSpectrumsTime.h"
#include "controllers/common/family/Families.h"

namespace dielectrics {

using namespace std;
using namespace common;

const std::string RunSpectrumsTime::TYPE = "dielectrics_run_spectrums_time";

RunSpectrumsTime::RunSpectrumsTime(const std::string& name) :
	RunSpectrums(name) {

	fr.setFlags(NOSAVE);
	N.setFlags(NOSAVE);
	N.setpoint.setFlags(NOSAVE);

	time.setFlags(NOSAVE | SPY);
	time.setpoint.setFlags(NOSAVE | SPY);
}

RunSpectrumsTime::~RunSpectrumsTime() {
}

void RunSpectrumsTime::start() {

	matlabController->requestType = RemoteMatlabReq::RUN_SPECTRUMS_TIME;
	matlabController->frMin = frMin();
	matlabController->frMax = frMax();
	matlabController->time = time.setpoint();
	matlabController->comment = comment();

	matlabController->startCommand();

	LogStream logStream = log(Level::s_Info);

	logStream << "Freq min " << frMin << " Freq Max " << frMax << " Time " << time.setpoint << " Comment '" << comment << "' ";
	logRunNumbers(logStream);
	logStream << endlog;
}

}
