/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef PERFECTCAENCFDDRIVER_H
#define PERFECTCAENCFDDRIVER_H

#include "CAENCfdState.h"

namespace caen_cfd {


/**
 * Perfect implementation of the vme card called Bit3 617,618,620.
 */
class PerfectCAENCfdDriver : public CAENCfdState {

public:

	/**
	 * Constructor.
	 *
	 * @param Link to the class which used the state
	 */
	PerfectCAENCfdDriver(CAENCfdDriver* owner);

	/**
	 * Destructor.
	 * Empty.
	 */
	virtual ~PerfectCAENCfdDriver();

	/*!
	 * \brief Init command implementation
	 */
	virtual void init();

	/*!
	 * \brief Clear command implementation
	 */
	virtual void clear();

	/*!
	 * \brief Reset command implementation
	 */
	virtual void reset();

	/*!
	 * \brief Write Param command implementation
	 */
	virtual void writeParam();

	/*!
	 * \brief Set acquisition mode command implementation
	 */
	virtual void setAcqMode();

	/*!
	 * \brief Read Infos command implementation
	 */
	virtual void readInfos();

	/*!
	 * \brief Read Infos command implementation
	 */
	virtual void readStatus();

	/*!
	 * \brief Set CFD mode parameters
	 */
	virtual void setCfdParam();

	/*!
	 * \brief Set bit in register
	 */
	virtual void registerSetBits(uint16_t addr, int32 startBit, int32 endBit, int32 val);
};

}
#endif //PERFECTCAENCFDDRIVER_H
