/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef PERFECTCAENSY2527DRIVER_H
#define PERFECTCAENSY2527DRIVER_H

#include "CAENSy2527State.h"

namespace caen_sy2527 {


/**
 * Perfect implementation of the vme card called Bit3 617,618,620.
 */
class PerfectCAENSy2527Driver : public CAENSy2527State {

public:

	/**
	 * Constructor.
	 *
	 * @param Link to the class which used the state
	 */
	PerfectCAENSy2527Driver(CAENSy2527Driver* owner);

	/**
	 * Destructor.
	 * Empty.
	 */
	virtual ~PerfectCAENSy2527Driver();

	/*!
	 * \brief Init command implementation
	 */
	virtual void init();

	/*!
	 * \brief Read Infos command implementation
	 */
	virtual void readInfos();

	/**
	 * Read the parameters.
	 */
	virtual void read(CAENSy2527BoardDriver* aBoard);

	/**
	 * Read the parameters.
	 */
	virtual void readParam(CAENSy2527BoardDriver* aBoard);

	/**
	 * Write the parameters.
	 */
	virtual void writeParam(CAENSy2527BoardDriver* aBoard);

	/**
	 * start the ramp.
	 */
	virtual void start(CAENSy2527BoardDriver* aBoard);

	/**
	 * stop the ramp.
	 */
	virtual void stop(CAENSy2527BoardDriver* aBoard);

	/**
	 * read status.
	 */
	virtual void readStatus(CAENSy2527BoardDriver* aBoard);

	/**
	 * power on.
	 */
	virtual void powerOn(CAENSy2527BoardDriver* aBoard);

	/**
	 * power off.
	 */
	virtual void powerOff(CAENSy2527BoardDriver* aBoard);
};

}
#endif //PERFECTCAENSY2527DRIVER_H
