/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef PERFECTDFK31AU03DRIVER_H
#define PERFECTDFK31AU03DRIVER_H

#include "Dfk31Au03State.h"

namespace dfk41au03 {

/*!
 * \class PerfectDfk31Au03Driver
 * \brief Perfect implementation class for the Dfk31Au03 device driver
 *
 * This class is a perfect implementation of Dfk31Au03 device driver.
 * On start command, all actual values become target's ones.
 */
class PerfectDfk31Au03Driver: public Dfk31Au03State {

public:

	/*!
	 * \brief Constructor
	 * \param[in] owner The device driver main class link
	 */
	PerfectDfk31Au03Driver(Dfk31Au03Driver* owner);

	/*!
	 * \brief Destructor
	 */
	virtual ~PerfectDfk31Au03Driver();

	/*!
	 * \brief Init command implementation
	 */
	virtual void init();

	/*!
	 * \brief Clear command implementation
	 */
	virtual void clear();

	/*!
	 * \brief Write Param command implementation
	 */
	virtual void writeParam();

	/*!
	 * \brief Read command implementation
	 */
	virtual void read();

	/*!
	 * \brief Synchronize Read command implementation
	 */
	virtual void synchroniseRead();

	/*!
	 * \brief Start command implementation
	 */
	virtual void start();

	/*!
	 * \brief Resume command implementation
	 */
	virtual void resume();

	/*!
	 * \brief Pause command implementation
	 */
	virtual void pause();

	/*!
	 * \brief Stop command implementation
	 */
	virtual void stop();

	/*!
	 * \brief Read Infos command implementation
	 */
	virtual void readStatus();

	/*!
	 * \brief Read Infos command implementation
	 */
	virtual void readInfos();

};

}
#endif //PERFECTDFK31AU03DRIVER_H
